@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use OptArgs ':all';
 
-our $VERSION = '0.1.0_4';
+our $VERSION = '0.1.0_5';
 
 $OptArgs::COLOUR = 1;
 $OptArgs::SORT   = 1;
@@ -101,6 +101,13 @@ opt alias => (
     comment => 'alias for future references to HUB',
 );
 
+opt debug_bs => (
+    isa     => 'Bool',
+    alias   => 'E',
+    comment => 'turn on bifsync debugging',
+    hidden  => 1,
+);
+
 # ------------------------------------------------------------------------
 # bif import
 # ------------------------------------------------------------------------
@@ -128,6 +135,13 @@ opt alias => (
     comment => 'alias for future references to HUB',
 );
 
+opt debug_bs => (
+    isa     => 'Bool',
+    alias   => 'E',
+    comment => 'turn on bifsync debugging',
+    hidden  => 1,
+);
+
 # ------------------------------------------------------------------------
 # bif new
 # ------------------------------------------------------------------------
@@ -283,6 +297,13 @@ opt message => (
     comment => 'optional comment for the associated update',
 );
 
+opt debug_bs => (
+    isa     => 'Bool',
+    alias   => 'E',
+    comment => 'turn on bifsync debugging',
+    hidden  => 1,
+);
+
 # ------------------------------------------------------------------------
 # bif list
 # ------------------------------------------------------------------------
@@ -445,6 +466,12 @@ arg hub => (
     comment => 'search for PATH in a hub',
 );
 
+opt uuid => (
+    isa     => 'Bool',
+    alias   => 'u',
+    comment => 'treat ID as a UUID',
+);
+
 opt full => (
     isa     => 'Bool',
     comment => 'display a more verbose current status',
@@ -639,6 +666,13 @@ arg hub => (
     comment => 'hub repository address or alias',
 );
 
+opt debug_bs => (
+    isa     => 'Bool',
+    alias   => 'E',
+    comment => 'turn on bifsync debugging',
+    hidden  => 1,
+);
+
 # ------------------------------------------------------------------------
 # bif upgrade
 # ------------------------------------------------------------------------
@@ -668,6 +702,12 @@ arg statement => (
     greedy  => 1,
 );
 
+opt noprint => (
+    isa     => 'Bool',
+    comment => 'do not print output but return a data structure',
+    alias   => 'n',
+);
+
 opt write => (
     isa     => 'Bool',
     comment => 'run with a writeable database (default is read-only)',
@@ -710,7 +750,7 @@ App::bif - OptArgs dispatch module for bif.
 
 =head1 VERSION
 
-0.1.0_4 (yyyy-mm-dd)
+0.1.0_5 (2014-04-11)
 
 =head1 SYNOPSIS
 
