@@ -8,7 +8,7 @@ use Coro;
 use Log::Any '$log';
 use Path::Tiny;
 
-our $VERSION = '0.1.0_4';
+our $VERSION = '0.1.0_5';
 
 sub run {
     my $opts = shift;
@@ -47,6 +47,8 @@ sub run {
     my $client = Bif::Client->new(
         db       => $dbw,
         hub      => $ctx->{hub},
+        debug    => $ctx->{debug},
+        debug_bs => $ctx->{debug_bs},
         on_error => sub {
             $error = shift;
             $cv->send;
@@ -135,7 +137,7 @@ bif-register -  register with a remote repository
 
 =head1 VERSION
 
-0.1.0_4 (yyyy-mm-dd)
+0.1.0_5 (2014-04-11)
 
 =head1 SYNOPSIS
 
