@@ -4,7 +4,7 @@ use warnings;
 use App::bif::Context;
 use Path::Tiny qw/path/;
 
-our $VERSION = '0.1.0_4';
+our $VERSION = '0.1.0_5';
 
 sub run {
     my $ctx = App::bif::Context->new(shift);
@@ -31,7 +31,7 @@ bif-upgrade - upgrade a repository
 
 =head1 VERSION
 
-0.1.0_4 (yyyy-mm-dd)
+0.1.0_5 (2014-04-11)
 
 =head1 SYNOPSIS
 
