@@ -8,7 +8,7 @@ use JSON;
 use Role::Basic qw/with/;
 use Sys::Cmd qw/spawn/;
 
-our $VERSION = '0.1.0_4';
+our $VERSION = '0.1.0_5';
 
 with 'Bif::Role::Sync';
 
@@ -17,6 +17,8 @@ has db => (
     required => 1,
 );
 
+has debug => ( is => 'ro' );
+
 has hub => (
     is       => 'ro',
     required => 1,
@@ -26,6 +28,8 @@ has child => ( is => 'rw' );
 
 has child_watcher => ( is => 'rw' );
 
+has debug_bs => ( is => 'ro' );
+
 has on_update => ( is => 'rw' );
 
 has status => ( is => 'rw', default => sub { [ 0, 'Undefined' ] } );
@@ -42,10 +46,18 @@ sub BUILD {
     my $self = shift;
 
     if ( $self->hub =~ m!^ssh://(.+?):(.+)! ) {
-        $self->child( spawn( 'ssh', $1, 'bifsync', $2 ) );
+        $self->child(
+            spawn( 'ssh', $1, 'bifsync', $self->debug_bs ? '--debug' : (), $2 )
+        );
     }
     else {
-        $self->child( spawn( 'bifsync', $self->hub ) );
+        $self->child(
+            spawn(
+                  'bifsync', $self->debug_bs
+                ? '--debug'
+                : (), $self->hub
+            )
+        );
     }
 
     $self->child_watcher(
@@ -58,6 +70,8 @@ sub BUILD {
     $self->rh(
         Coro::Handle->new_from_fh( $self->child->stdout, timeout => 5 ) );
     $self->wh( Coro::Handle->new_from_fh( $self->child->stdin, timeout => 5 ) );
+
+    $self->json->pretty if $self->debug;
     return;
 }
 
@@ -65,13 +79,13 @@ sub register {
     my $self = shift;
     my $info = shift;
 
-    $self->write( [ 'IMPORT', 'repo' ] );
+    $self->write( 'IMPORT', 'repo' );
 
-    my $msg = $self->read;
-    if ( $msg->[0] eq 'EXPORT' and $msg->[1] eq 'repo' ) {
+    my ( $action, $type ) = $self->read;
+    if ( $action eq 'EXPORT' and $type eq 'repo' ) {
         return $self->real_import_repo;
     }
-    return $msg->[0];
+    return $action;
 }
 
 sub sync_repo {
@@ -86,27 +100,27 @@ sub sync_repo {
         where => { 'r.id' => $id },
     );
 
-    $self->write( [ 'SYNC', 'repo', $repo->{uuid}, $repo->{hash} ] );
+    $self->write( 'SYNC', 'repo', $repo->{uuid}, $repo->{hash} );
 
-    my $msg = $self->read;
-    if ( $msg->[0] eq 'SYNC' and $msg->[1] eq 'repo' ) {
+    my ( $action, $type ) = $self->read;
+    if ( $action eq 'SYNC' and $type eq 'repo' ) {
         return $self->real_sync_repo( $repo->{id} );
     }
 
-    return $msg->[0];
+    return $action;
 }
 
 sub export_project {
     my $self  = shift;
     my $pinfo = shift;
 
-    $self->write( [ 'EXPORT', 'project', $pinfo->{uuid}, $pinfo->{path} ] );
+    $self->write( 'EXPORT', 'project', $pinfo->{uuid}, $pinfo->{path} );
 
-    my $msg = $self->read;
-    if ( $msg->[0] eq 'IMPORT' and $msg->[1] eq 'project' ) {
+    my ( $action, $type ) = $self->read;
+    if ( $action eq 'IMPORT' and $type eq 'project' ) {
         return $self->real_export_project( $pinfo->{id} );
     }
-    return $msg->[0];
+    return $action;
 }
 
 sub import_project {
@@ -119,10 +133,10 @@ sub import_project {
         where  => { 'p.id' => $pinfo->{id} },
     );
 
-    $self->write( [ 'SYNC', 'project', $pinfo->{uuid}, $hash ] );
+    $self->write( 'SYNC', 'project', $pinfo->{uuid}, $hash );
 
-    my $msg = $self->read;
-    if ( $msg->[0] eq 'SYNC' and $msg->[1] eq 'project' ) {
+    my ( $action, $type ) = $self->read;
+    if ( $action eq 'SYNC' and $type eq 'project' ) {
         my $result = $self->real_sync_project( $pinfo->{id} );
         if ( $result eq 'ProjectImported' or $result eq 'ProjectMatch' ) {
             $self->db->xdo(
@@ -134,7 +148,7 @@ sub import_project {
         }
         return $result;
     }
-    elsif ( $msg->[0] eq 'ProjectMatch' ) {
+    elsif ( $action eq 'ProjectMatch' ) {
         $self->db->xdo(
             update => 'projects',
             set    => 'local = 1',
@@ -143,13 +157,13 @@ sub import_project {
         return 'ProjectImported';
     }
 
-    $self->write( [ 'ExpectedSync', 'Expected SYNC' ] );
+    $self->write( 'ExpectedSync', 'Expected SYNC' );
     return 'ExpectedSync';
 }
 
 sub disconnect {
     my $self = shift;
-    $self->write( ['QUIT'] ) if $self->child_watcher;
+    $self->write('QUIT') if $self->child_watcher;
     $self->child_watcher(undef);
 
     return unless my $child = $self->child;
